@@ -14,6 +14,15 @@ class AxonaRecordingInterface(BaseRecordingExtractorInterface):
     :py:class:`~spikeinterface.extractors.AxonaRecordingExtractor`."""
 
     def __init__(self, file_path: FilePathType, verbose: bool = True):
+        """
+
+        Parameters
+        ----------
+        file_path: FilePathType
+            Path to .bin file.
+        verbose: bool, optional, default: True
+        """
+
         super().__init__(file_path=file_path, all_annotations=True, verbose=verbose)
         self.source_data = dict(file_path=file_path, verbose=verbose)
         self.metadata_in_set_file = self.recording_extractor.neo_reader.file_parameters["set"]["file_header"]
@@ -23,7 +32,6 @@ class AxonaRecordingInterface(BaseRecordingExtractorInterface):
         self.recording_extractor.set_channel_groups(tetrode_id)
 
     def extract_nwb_file_metadata(self):
-
         raw_annotations = self.recording_extractor.neo_reader.raw_annotations
         session_start_time = raw_annotations["blocks"][0]["segments"][0]["rec_datetime"]
         session_description = self.metadata_in_set_file["comments"]
@@ -67,7 +75,6 @@ class AxonaRecordingInterface(BaseRecordingExtractorInterface):
         return ecephys_metadata
 
     def get_metadata(self):
-
         metadata = super().get_metadata()
 
         nwbfile_metadata = self.extract_nwb_file_metadata()
@@ -115,7 +122,6 @@ class AxonaLFPDataInterface(BaseLFPExtractorInterface):
         )
 
     def __init__(self, file_path: FilePathType):
-
         data = read_all_eeg_file_lfp_data(file_path).T
         sampling_frequency = get_eeg_sampling_frequency(file_path)
         super().__init__(traces_list=[data], sampling_frequency=sampling_frequency)
