@@ -17,10 +17,9 @@ class BiocamRecordingInterface(BaseRecordingExtractorInterface):
 
         Parameters
         ----------
-        folder_path: string or Path
+        folder_path : string or Path
             Path to the .bwr file.
-        verbose: boolean
+        verbose : bool, default: True
             Allows verbose.
-            Default is True.
         """
         super().__init__(file_path=file_path, verbose=verbose)
