@@ -14,7 +14,8 @@ class KiloSortSortingInterface(BaseSortingExtractorInterface):
         ----------
         folder_path: str or Path
             Path to the output Phy folder (containing the params.py)
-        keep_good_only: bool
+        keep_good_only: bool, default: False
             If True, only Kilosort-labeled 'good' units are returned
+        verbose: bool, default: True
         """
         super().__init__(folder_path=folder_path, keep_good_only=keep_good_only, verbose=verbose)
