@@ -1,5 +1,6 @@
 """Authors: Heberto Mayorquin, Luiz Tauffer."""
 from typing import Optional
+from warnings import warn
 
 from ..baserecordingextractorinterface import BaseRecordingExtractorInterface
 from ..basesortingextractorinterface import BaseSortingExtractorInterface
@@ -24,14 +25,36 @@ class OpenEphysRecordingInterface(BaseRecordingExtractorInterface):
     def __init__(
         self,
         folder_path: FolderPathType,
-        experiment_id: Optional[int] = 0,
-        recording_id: Optional[int] = 0,
+        experiment_id: int = 0,
+        recording_id: int = 0,
         stub_test: bool = False,
         verbose: bool = True,
         spikeextractors_backend: bool = False,
     ):
+        """
+        Initialize reading of OpenEphys binary recording.
+
+        Parameters
+        ----------
+        folder_path: FolderPathType
+            Path to OpenEphys directory.
+        experiment_id : int, default: 0
+        recording_id : int, default: 0
+        stub_test : bool, default: False
+        verbose : bool, default: True
+        spikeextractors_backend : bool, default: False
+        """
         self.spikeextractors_backend = spikeextractors_backend
         if spikeextractors_backend:
+            # TODO: Remove spikeextractors backend
+            warn(
+                message=(
+                    "Interfaces using a spikeextractors backend will soon be deprecated! "
+                    "Please use the SpikeInterface backend instead."
+                ),
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
             from spikeextractors import OpenEphysRecordingExtractor
             from spikeinterface.core.old_api_utils import OldToNewRecording
 
