@@ -1,6 +1,9 @@
 """Authors: Heberto Mayorquin, Cody Baker."""
+from warnings import warn
+from typing import Optional
+
 from ..baserecordingextractorinterface import BaseRecordingExtractorInterface
-from ....utils import FilePathType, OptionalFilePathType, OptionalArrayType
+from ....utils import FilePathType, ArrayType
 
 
 class SpikeGadgetsRecordingInterface(BaseRecordingExtractorInterface):
@@ -19,8 +22,8 @@ class SpikeGadgetsRecordingInterface(BaseRecordingExtractorInterface):
     def __init__(
         self,
         file_path: FilePathType,
-        gains: OptionalArrayType = None,
-        probe_file_path: OptionalFilePathType = None,
+        gains: Optional[ArrayType] = None,
+        probe_file_path: Optional[FilePathType] = None,
         verbose: bool = True,
         spikeextractors_backend: bool = False,
     ):
@@ -31,19 +34,28 @@ class SpikeGadgetsRecordingInterface(BaseRecordingExtractorInterface):
         ----------
         file_path : FilePathType
             Path to the .rec file.
-        gains : ArrayType, optional
+        gains : array_like, optional
             The early versions of SpikeGadgest do not automatically record the conversion factor ('gain') of the
             acquisition system. Thus it must be specified either as a single value (if all channels have the same gain)
             or an array of values for each channel.
         probe_file_path : FilePathType, optional
             Set channel properties and geometry through a .prb file.
             See https://github.com/SpikeInterface/probeinterface for more information.
-        spikeextractors_backend : bool
-            False by default. When True the interface uses the old extractor from the spikextractors library instead
+        spikeextractors_backend : bool, default: False
+            When True the interface uses the old extractor from the spikextractors library instead
             of a new spikeinterface object.
         """
 
         if spikeextractors_backend:
+            # TODO: Remove spikeextractors backend
+            warn(
+                message=(
+                    "Interfaces using a spikeextractors backend will soon be deprecated! "
+                    "Please use the SpikeInterface backend instead."
+                ),
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
             from spikeextractors import SpikeGadgetsRecordingExtractor, load_probe_file
             from spikeinterface.core.old_api_utils import OldToNewRecording
 
