@@ -1,7 +1,7 @@
 from typing import Optional
 
 from ..basesegmentationextractorinterface import BaseSegmentationExtractorInterface
-from ....utils import FilePathType, FloatType
+from ....utils import FilePathType
 
 
 class ExtractSegmentationInterface(BaseSegmentationExtractorInterface):
@@ -10,10 +10,19 @@ class ExtractSegmentationInterface(BaseSegmentationExtractorInterface):
     def __init__(
         self,
         file_path: FilePathType,
-        sampling_frequency: FloatType,
+        sampling_frequency: float,
         output_struct_name: Optional[str] = None,
         verbose: bool = True,
     ):
+        """
+
+        Parameters
+        ----------
+        file_path : FilePathType
+        sampling_frequency : float
+        output_struct_name : str, optional
+        verbose: bool, default : True
+        """
         self.verbose = verbose
         super().__init__(
             file_path=file_path,
