@@ -1,5 +1,5 @@
 from ..baseimagingextractorinterface import BaseImagingExtractorInterface
-from ....utils import FilePathType, FloatType
+from ....utils import FilePathType
 
 
 class TiffImagingInterface(BaseImagingExtractorInterface):
@@ -11,5 +11,14 @@ class TiffImagingInterface(BaseImagingExtractorInterface):
         source_schema["properties"]["file_path"]["description"] = "Path to Tiff file."
         return source_schema
 
-    def __init__(self, file_path: FilePathType, sampling_frequency: FloatType, verbose: bool = True):
+    def __init__(self, file_path: FilePathType, sampling_frequency: float, verbose: bool = True):
+        """
+        Initialize reading of TIFF file.
+
+        Parameters
+        ----------
+        file_path : FilePathType
+        sampling_frequency : float
+        verbose : bool, default: True
+        """
         super().__init__(file_path=file_path, sampling_frequency=sampling_frequency, verbose=verbose)
